==> youqian-api-1.5.12-sources.jar: com/youqian/api/remoteservice/RemoteUserService.java <==
package com.youqian.api.remoteservice;

import com.youqian.api.dto.accesslog.AccessInviteDto;
import com.youqian.api.dto.accesslog.AccessLogExtDto;
import com.youqian.api.dto.platformuser.PlatformUserDto;
import com.youqian.api.params.LiveInviteParam;
import com.youqian.api.request.FocusListRequest;
import com.youqian.api.request.UserListRequest;
import com.youqian.api.response.AccessInviteResult;
import com.youqian.api.response.AreaRatioResult;
import com.youqian.api.response.CustomerRatioResult;
import com.youqian.api.response.LiveInviteResult;
import com.youqian.api.response.PageResult;
import com.youqian.api.response.UserFocusResult;
import com.youqian.api.response.WatchLiveGoodsResult;
import com.youqian.auth.api.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import com.youqian.api.request.TokenVRequest;
import com.youqian.api.response.PlatformUserResponse;

import java.util.List;

/**
 * @author tengtuox
 * @date 2020/1/3
 * @description
 */
@AdvancedFeignClient
public interface RemoteUserService {

    /**
     * 根据openId获取用户信息
     *
     * @param tokenRequest openId&type
     * @return PlatformUser
     * @throws BizException 用户不存在
     */
    PlatformUserResponse getUserByOpenId(TokenVRequest tokenRequest) throws BizException;

    /**
     * 定时任务处理accessLog的停留时间
     * @throws BizException
     */
    void accessLogJob() throws BizException;

    /**
     * 根据UserId获取用户信息
     *
     * @param userId userId
     * @return PlatformUserDto
     * @throws BizException 用户不存在
     */
    PlatformUserDto getByUserId(Long userId) throws BizException;
    /**
     * 根据UserId组获取用户信息
     *
     * @param userIds userId组
     * @return PlatformUserDto
     * @throws BizException 用户不存在
     */
    List<PlatformUserDto> getByUserIds(List<Long> userIds) throws BizException;

    /**
     * 根据用户ID 查找列表
     *  @param userListRequest 列表参数
     *  @return
     */
    List<PlatformUserDto> selectByUserList(UserListRequest userListRequest);

    /**
     * 根据用户ID 统计
     *  @param userListRequest 列表参数
     *  @return
     */
    Integer countUserList(UserListRequest userListRequest);

    /**
     * 查询用户进入直播间的线索
     * @param userId 用户ID
     * @param merchantId 商户ID
     * @param liveRoomId 直播间ID
     * @return list
     */
    List<AccessLogExtDto> selectByAccessLogExt(Long userId,Long liveRoomId,Long merchantId);

    /**
     * 查询直播间邀约统计
     * @param liveRoomId 直播间ID
     * @return 统计结果
     */
    LiveInviteResult selectInviteLiveStatistical(Long liveRoomId);

    /**
     * 查询客户的信息
     * @param liveRoomId 直播间ID
     * @param userIds 用户ID
     * @return 线索
     */
    List<AccessInviteDto> selectByAccessClue(Long liveRoomId, List<Long> userIds);

    /**
     * 查询直播间的邀约情况
     * @param liveRoomId 直播间ID
     * @return 邀约线索
     */
    List<AccessInviteDto> selectInviteByLiveRoom(Long liveRoomId);

    /**
     * 查询直播间的邀约列表
     * @param liveRoomIds 直播间IDs
     * @return 邀约线索
     */
    List<AccessInviteDto> selectInviteByLiveRoomIds(List<Long> liveRoomIds);

    /**
     * 定时任务:待办事项每月任务项，清零
     */
    void updateBackLog();

    /**
     * 直播邀约
     * @param liveInviteParam 邀约参数
     *
     */
    PageResult<AccessInviteResult> liveInvite(LiveInviteParam liveInviteParam);

    /**
     * 查询邀约
     */
    Integer accessInvite(Long liveRoomId);

    /**
     * 查询统计记录
     */
    List<AccessLogExtDto> selectByMerchantIdsAndType(List<Long> merchantIds);

    /**
     * 用户关注商户列表
     */
    PageResult<UserFocusResult> focusList(FocusListRequest focusListRequest);

    /**
     * 直播商品的查看次数
     */
    List<WatchLiveGoodsResult> getLiveGoodsWatch(Long liveRoomId, List<Long> goodsIds);

    /**
     * 地域分布
     */
    List<AreaRatioResult> selectAreaRatio(List<Long> userIds, Long merchantId,Integer all);

    /**
     * 更新员工邀约查看回看次数
     */
    void updateAccessInviteWatchBack(Long userId,Long liveRoomId,Integer liveWatchCount);

    /**
     * 查询用户是否首次看回看
     */
    boolean selectHasFirstWatchLiveWatch(Long userId,Long merchantId);

    /**
     * 询价总数
     */
    Integer enquiryCount(Long userId,Long liveRoomId);
}

==> youqian-api-1.5.40-sources.jar: com/youqian/api/remoteservice/RemoteUserService.java <==
package com.youqian.api.remoteservice;

import com.youqian.api.dto.accesslog.AccessInviteDto;
import com.youqian.api.dto.accesslog.AccessLogDto;
import com.youqian.api.dto.accesslog.AccessLogExtDto;
import com.youqian.api.dto.merchant.MerchantStoreFollowDto;
import com.youqian.api.dto.platformuser.PlatformUserDto;
import com.youqian.api.params.LiveInviteParam;
import com.youqian.api.request.FocusListRequest;
import com.youqian.api.request.UserListRequest;
import com.youqian.api.response.AccessInviteResult;
import com.youqian.api.response.AreaRatioResult;
import com.youqian.api.response.CustomerRatioResult;
import com.youqian.api.response.LiveInviteResult;
import com.youqian.api.response.PageResult;
import com.youqian.api.response.UserFocusResult;
import com.youqian.api.response.WatchLiveGoodsResult;
import com.youqian.auth.api.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import com.youqian.api.request.TokenVRequest;
import com.youqian.api.response.PlatformUserResponse;

import java.util.List;

/**
 * @author tengtuox
 * @date 2020/1/3
 * @description
 */
@AdvancedFeignClient
public interface RemoteUserService {

    /**
     * 根据openId获取用户信息
     *
     * @param tokenRequest openId&type
     * @return PlatformUser
     * @throws BizException 用户不存在
     */
    PlatformUserResponse getUserByOpenId(TokenVRequest tokenRequest) throws BizException;

    /**
     * 定时任务处理accessLog的停留时间
     * @throws BizException
     */
    void accessLogJob() throws BizException;

    /**
     * 根据UserId获取用户信息
     *
     * @param userId userId
     * @return PlatformUserDto
     * @throws BizException 用户不存在
     */
    PlatformUserDto getByUserId(Long userId) throws BizException;
    /**
     * 根据UserId组获取用户信息
     *
     * @param userIds userId组
     * @return PlatformUserDto
     * @throws BizException 用户不存在
     */
    List<PlatformUserDto> getByUserIds(List<Long> userIds) throws BizException;

    /**
     * 根据用户ID 查找列表
     *  @param userListRequest 列表参数
     *  @return
     */
    List<PlatformUserDto> selectByUserList(UserListRequest userListRequest);

    /**
     * 根据用户ID 统计
     *  @param userListRequest 列表参数
     *  @return
     */
    Integer countUserList(UserListRequest userListRequest);

    /**
     * 查询用户进入直播间的线索
     * @param userId 用户ID
     * @param merchantId 商户ID
     * @param liveRoomId 直播间ID
     * @return list
     */
    List<AccessLogExtDto> selectByAccessLogExt(Long userId,Long liveRoomId,Long merchantId);

    /**
     * 查询直播间邀约统计
     * @param liveRoomId 直播间ID
     * @return 统计结果
     */
    LiveInviteResult selectInviteLiveStatistical(Long liveRoomId);

    /**
     * 查询客户的信息
     * @param liveRoomId 直播间ID
     * @param userIds 用户ID
     * @return 线索
     */
    List<AccessInviteDto> selectByAccessClue(Long liveRoomId, List<Long> userIds);

    /**
     * 查询直播间的邀约情况
     * @param liveRoomId 直播间ID
     * @return 邀约线索
     */
    List<AccessInviteDto> selectInviteByLiveRoom(Long liveRoomId);

    /**
     * 查询直播间的邀约列表
     * @param liveRoomIds 直播间IDs
     * @return 邀约线索
     */
    List<AccessInviteDto> selectInviteByLiveRoomIds(List<Long> liveRoomIds);

    /**
     * 定时任务:待办事项每月任务项，清零
     */
    void updateBackLog();

    /**
     * 直播邀约
     * @param liveInviteParam 邀约参数
     *
     */
    PageResult<AccessInviteResult> liveInvite(LiveInviteParam liveInviteParam);

    /**
     * 查询邀约
     */
    Integer accessInvite(Long liveRoomId);

    /**
     * 查询统计记录
     */
    List<AccessLogExtDto> selectByMerchantIdsAndType(List<Long> merchantIds);

    /**
     * 用户关注商户列表
     */
    PageResult<UserFocusResult> focusList(FocusListRequest focusListRequest);

    /**
     * 直播商品的查看次数
     */
    List<WatchLiveGoodsResult> getLiveGoodsWatch(Long liveRoomId, List<Long> goodsIds);

    /**
     * 更新员工邀约查看回看次数
     */
    void updateAccessInviteWatchBack(Long userId,Long liveRoomId,Integer liveWatchCount);


    /**
     * 查询用户是否首次看回看
     */
    boolean selectHasFirstWatchLiveWatch(Long userId,Long merchantId);

    /**
     * 询价总数
     */
    Integer enquiryCount(Long userId,Long liveRoomId);

    /**
<<<<<<< HEAD
     * 用户访问客户商户
     */
    List<AccessLogDto> selectByUserAccessLog(Long userId,Long merchantId);

    /**
     * 用户线索
     */
    List<AccessLogExtDto> selectByUserAllAccessLogExt(Long userId,Long merchantId);

    /**
     * 用户关注店铺信息
     */
    MerchantStoreFollowDto selectMerchantFollow(Long userId, Long merchantId);

    /**
     * 查询用户总红包数
     */
    Integer selectUserRaffleCount(List<Long> liveRoomIds,Long userId);

    /**
     * 根据unionId获取用户信息
     *
     * @param unionId unionId
     * @return PlatformUser
     */
    PlatformUserDto getUserByUnionId(String unionId);
}
